Глава 2. Установка
Пред. |  | След.

## Глава 2. Установка

Предпочтительный способ установки ardj — через Python Package Index, с помощью утилиты pip. В большинстве современных UNIX-систем это делается одной командой:

    sudo pip install ardj

Если в вашей системе не установлена утилита pip — установите её.

Удаление ardj:

    sudo pip uninstall ardj

Обновление до последней версии:

    sudo pip install --upgrade ardj

Пред. |  | След.
Рейтинг композиций | Начало | Глава 3. Настройка